diff --git a/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts.py b/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts.py
index 823989a62c338070e03a2679923c8021bb7227a0..a2c8c39bee5a585c9dbd9118dccde6e94a95e552 100644
--- a/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts.py
+++ b/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
 from AthenaCommon.AlgSequence import AlgSequence
@@ -122,7 +122,7 @@ include( "CaloRec/CaloTopoCluster_jobOptions.py" )
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_SerialOnly.py b/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_SerialOnly.py
index 10edd30faacb036547f349b43063b456896663ea..71c181da3006caafc966b30b75ed7736006cfd28 100644
--- a/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_SerialOnly.py
+++ b/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_SerialOnly.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
 from AthenaCommon.AlgSequence import AlgSequence
@@ -96,7 +96,7 @@ include( "CaloRec/CaloTopoCluster_jobOptions.py" )
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_alt.py b/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_alt.py
index f123beb1a01e8ddf844b22ce8adc9708854b7aec..e6fe68c6c4daf47ba0250fd6f5e5a601d2c4bc13 100644
--- a/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_alt.py
+++ b/Calorimeter/CaloExample/CaloHiveEx/share/CaloHiveExOpts_alt.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
 
@@ -238,7 +238,7 @@ if useJets:
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Calorimeter/CaloExample/CaloHiveEx/share/old/CaloHiveExOpts.py b/Calorimeter/CaloExample/CaloHiveEx/share/old/CaloHiveExOpts.py
index bf364f05c5e6a55fcdd040f859b66dcbf99ed365..b1c675b68529da93a4f53fe6a162b6fae422bca1 100644
--- a/Calorimeter/CaloExample/CaloHiveEx/share/old/CaloHiveExOpts.py
+++ b/Calorimeter/CaloExample/CaloHiveEx/share/old/CaloHiveExOpts.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
 
@@ -212,7 +212,7 @@ if useJets:
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Control/AthenaExamples/AthExThinning/share/WriteThinnedData_jobOptions.py b/Control/AthenaExamples/AthExThinning/share/WriteThinnedData_jobOptions.py
index 49813db8682d4694b2368e5cae499df26a6dea21..445f9d1a01305a136a420e8a68efdf28f3c1e83f 100644
--- a/Control/AthenaExamples/AthExThinning/share/WriteThinnedData_jobOptions.py
+++ b/Control/AthenaExamples/AthExThinning/share/WriteThinnedData_jobOptions.py
@@ -61,7 +61,7 @@ topSequence += WriteThinnedData(
 # POOL Persistency
 #--------------------------------------------------------------
 import AthenaPoolCnvSvc.WriteAthenaPool as wap
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 
 if 'OUTPUT' not in dir():
    OUTPUT = "thinned.%s" % INPUT[0]
diff --git a/Control/DataModelTest/DataModelRunTests/share/AuxDataTestRead_jo.py b/Control/DataModelTest/DataModelRunTests/share/AuxDataTestRead_jo.py
index 6c100e7d0afb1e1386cdcc05efde09b8cc9cc934..a35e89759bfe93fa68f256f22dde7e1fad58c4c9 100755
--- a/Control/DataModelTest/DataModelRunTests/share/AuxDataTestRead_jo.py
+++ b/Control/DataModelTest/DataModelRunTests/share/AuxDataTestRead_jo.py
@@ -67,7 +67,7 @@ topSequence += DMTest__AuxDataTestDecor ('AuxDataTestDecor1',
                                          Offset = 100)
 
 # Stream's output file
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 Stream1 = createOutputStream( "Stream1", asAlg = True, noTag = True )
 Stream1.OutputFile =   "auxdata2.root"
 Stream1.ItemList   += fullItemList # List of DO's to write out
diff --git a/Control/DataModelTest/DataModelRunTests/share/AuxDataTestTypelessRead_jo.py b/Control/DataModelTest/DataModelRunTests/share/AuxDataTestTypelessRead_jo.py
index d7f9f5e7505280c75eb01c019967fb23e3b36eaf..0057f872185d46d574c44fc6342e8ca59c66be18 100644
--- a/Control/DataModelTest/DataModelRunTests/share/AuxDataTestTypelessRead_jo.py
+++ b/Control/DataModelTest/DataModelRunTests/share/AuxDataTestTypelessRead_jo.py
@@ -44,7 +44,7 @@ fullItemList+=["DMTest::BAuxVec#copy_bauxvec"]
 fullItemList+=["DMTest::BAuxStandalone#copy_b"]
 
 # Stream's output file
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 Stream1 = createOutputStream( "Stream1", noTag = True )
 Stream1.OutputFile =   "auxdata3.root"
 # List of DO's to write out
diff --git a/Control/DataModelTest/DataModelRunTests/share/AuxDataTestWrite_jo.py b/Control/DataModelTest/DataModelRunTests/share/AuxDataTestWrite_jo.py
index 5cd7c5c8f176d6e36c3a3397f1b36e9dce3629d2..aae03d588024c7e52da596cadb29a7fedf7cb732 100755
--- a/Control/DataModelTest/DataModelRunTests/share/AuxDataTestWrite_jo.py
+++ b/Control/DataModelTest/DataModelRunTests/share/AuxDataTestWrite_jo.py
@@ -52,7 +52,7 @@ fullItemList+=["DMTest::BAuxVec#bauxvec"]
 fullItemList+=["DMTest::BAuxStandalone#b"]
 
 # Stream's output file
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 Stream1 = createOutputStream( "Stream1", noTag = True )
 Stream1.OutputFile =   "auxdata.root"
 # List of DO's to write out
diff --git a/Control/DataModelTest/DataModelRunTests/share/DataModelTestRead_jo.py b/Control/DataModelTest/DataModelRunTests/share/DataModelTestRead_jo.py
index 55968bf7792f9d49270b308dd77bda73b4c78cb4..151ce91db35849296f29237937b8aa6027211750 100755
--- a/Control/DataModelTest/DataModelRunTests/share/DataModelTestRead_jo.py
+++ b/Control/DataModelTest/DataModelRunTests/share/DataModelTestRead_jo.py
@@ -53,7 +53,7 @@ fullItemList+=["DMTest::ELVec#elvec"]
 fullItemList+=["DMTest::ELVec#elv_remap"]
 
 # Stream's output file
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 Stream1 = createOutputStream( "Stream1", noTag = True )
 Stream1.OutputFile =   "SimplePoolFile2.root"
 # List of DO's to write out
diff --git a/Control/DataModelTest/DataModelRunTests/share/DataModelTestWrite_jo.py b/Control/DataModelTest/DataModelRunTests/share/DataModelTestWrite_jo.py
index 895b34533b7ed3c8002db0e9d0c67aed8a3f8212..cba2f860f2604bcac088a1e6c4d39e96e6ea06db 100755
--- a/Control/DataModelTest/DataModelRunTests/share/DataModelTestWrite_jo.py
+++ b/Control/DataModelTest/DataModelRunTests/share/DataModelTestWrite_jo.py
@@ -55,7 +55,7 @@ fullItemList+=["DMTest::ELVec#elvec"]
 fullItemList+=["DMTest::ELVec#elv_remap"]
 
 # Stream's output file
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 Stream1 = createOutputStream( "Stream1", noTag = True )
 Stream1.OutputFile =   "SimplePoolFile.root"
 # List of DO's to write out
diff --git a/Database/AthenaPOOL/AthenaPoolCnvSvc/python/WriteAthenaPool.py b/Database/AthenaPOOL/AthenaPoolCnvSvc/python/WriteAthenaPool.py
index 9b3b086c1865d52e360059fe08a623b7b089bc5e..e484ee2ef16cef9445a464475fc6e56ead4537ba 100644
--- a/Database/AthenaPOOL/AthenaPoolCnvSvc/python/WriteAthenaPool.py
+++ b/Database/AthenaPOOL/AthenaPoolCnvSvc/python/WriteAthenaPool.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 
 ## @file WriteAthenaPool_jobOptions.py
 ## @brief AthenaPool job options file for writing event objects.
@@ -16,7 +16,7 @@
 #==============================================================
 
 ## import the default class to create output streams
-from OutputStreamAthenaPool.OutputStreamAthenaPool import AthenaPoolOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import AthenaPoolOutputStream
 
 ## export the default class to create output streams
 __all__ = [ 'AthenaPoolOutputStream' ]
diff --git a/Database/AthenaPOOL/AthenaPoolExample/AthenaPoolExampleAlgorithms/share/AthenaPoolExample_WCondJobOptions.py b/Database/AthenaPOOL/AthenaPoolExample/AthenaPoolExampleAlgorithms/share/AthenaPoolExample_WCondJobOptions.py
index 6d7e19be64831ef2760b1ee5793f4746099b4250..76c5dcc92cea44d8bf069f6fda5132658527952d 100755
--- a/Database/AthenaPOOL/AthenaPoolExample/AthenaPoolExampleAlgorithms/share/AthenaPoolExample_WCondJobOptions.py
+++ b/Database/AthenaPOOL/AthenaPoolExample/AthenaPoolExampleAlgorithms/share/AthenaPoolExample_WCondJobOptions.py
@@ -46,7 +46,7 @@ svcMgr.PoolSvc.WriteCatalog = "file:Catalog1.xml"
 #---   Secondary Write portion  ----- Don't change it !!!
 #--------------------------------------------------------------
 # Load the OutputStream
-from OutputStreamAthenaPool.OutputStreamAthenaPool import AthenaPoolOutputConditionStream
+from OutputStreamAthenaPool.CreateOutputStreams import AthenaPoolOutputConditionStream
 Stream1 = AthenaPoolOutputConditionStream( "Stream1", "SimplePoolFile4.root" )
 Stream1.ObjectList += [ "ExampleHitContainer#PedestalWriteData" ]
 
diff --git a/Database/AthenaPOOL/OutputStreamAthenaPool/python/OutputStreamAthenaPool.py b/Database/AthenaPOOL/OutputStreamAthenaPool/python/CreateOutputStreams.py
similarity index 100%
rename from Database/AthenaPOOL/OutputStreamAthenaPool/python/OutputStreamAthenaPool.py
rename to Database/AthenaPOOL/OutputStreamAthenaPool/python/CreateOutputStreams.py
diff --git a/Event/EventBookkeeperTools/share/TestCutFlowSvcOutput.py b/Event/EventBookkeeperTools/share/TestCutFlowSvcOutput.py
index 2b9979a55e090701e090362f2335e046829d43f3..2ea25b2034176c8129f50f0f79d2b38ea22244c7 100644
--- a/Event/EventBookkeeperTools/share/TestCutFlowSvcOutput.py
+++ b/Event/EventBookkeeperTools/share/TestCutFlowSvcOutput.py
@@ -57,7 +57,7 @@ alg.cut2 = 12
 topSequence += alg
 
 # output options
-from OutputStreamAthenaPool.OutputStreamAthenaPool import AthenaPoolOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import AthenaPoolOutputStream
 Stream1 = AthenaPoolOutputStream('Stream1', 'OutputAOD.root', asAlg=True)
 Stream1.ItemList = ['xAOD::EventInfo#*', 'xAOD::EventAuxInfo#*']
 Stream1.MetadataItemList += ['xAOD::CutBookkeeperContainer#CutBookkeepers', 'xAOD::CutBookkeeperAuxContainer#CutBookkeepersAux.']
diff --git a/Generators/EmbeddedTrackGenerator/share/EmbeddedGeneratorCommon.py b/Generators/EmbeddedTrackGenerator/share/EmbeddedGeneratorCommon.py
index 2f8884d9be480e5fd74708040ae7202952ad9747..fd306098f9d7a82ab8555ee75111fb1396a840d4 100644
--- a/Generators/EmbeddedTrackGenerator/share/EmbeddedGeneratorCommon.py
+++ b/Generators/EmbeddedTrackGenerator/share/EmbeddedGeneratorCommon.py
@@ -35,7 +35,7 @@ sg2 = StoreGateSvc("InputData_Event_SG")
 #================================================================
 # Output
 
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 outStream = createOutputStream( "EmbeddedGeneratorOut" )
 outStream.Store = ServiceMgr.StoreGateSvc
 outStream.OutputFile  = OutputFile
diff --git a/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_egamma_fromESD.py b/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_egamma_fromESD.py
index 91c32691b8d33568cc9b40478a9481e53b49ee0f..4fc8cbf19efadfa16c55b98e90f4c6823f39ea2a 100644
--- a/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_egamma_fromESD.py
+++ b/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_egamma_fromESD.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2018 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
 from AthenaCommon.AlgSequence import AlgSequence
@@ -163,7 +163,7 @@ include( "egammaRec/egammaRec_jobOptions.py" )
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_refit_fromESD.py b/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_refit_fromESD.py
index 2be990badbaeb6101c4f377a89f0c2632252212e..5f80dca0ab22d31489488449dd67483ad3d58386 100644
--- a/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_refit_fromESD.py
+++ b/Reconstruction/RecExample/RecExRecoTest/share/RecExRecoTest_ART_refit_fromESD.py
@@ -163,7 +163,7 @@ topSequence += MyReFitTrack
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_CaloHiveExOpts.py b/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_CaloHiveExOpts.py
index efca8db21ade90268c6071c17a5684a757f43b30..287a1249f5f92b6744d901eb9d96727b77713f9c 100644
--- a/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_CaloHiveExOpts.py
+++ b/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_CaloHiveExOpts.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 
 from AthenaCommon.AlgSequence import AlgSequence
@@ -129,7 +129,7 @@ include( "CaloRec/CaloTopoCluster_jobOptions.py" )
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_PFlowHiveExOpts.py b/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_PFlowHiveExOpts.py
index 5fc9fb17d94432237522c3f5ec6001c82c712f3a..1bf9061ef8288a19ac3122a47bc48c9015e51614 100644
--- a/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_PFlowHiveExOpts.py
+++ b/Reconstruction/RecExample/RecJobTransformTests/share/RecJobTransformTests_PFlowHiveExOpts.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 # Runs calorimeter clustering reconstruction - this part is taken from CaloHiveExOpts.py
 # Additional configuration runs particle flow MT algorithms and sets up items needed for track to calorimeter extrapolation
@@ -177,7 +177,7 @@ topSequence += PFClusterSelector
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Reconstruction/eflowRec/share/PFlowHiveExOpts.py b/Reconstruction/eflowRec/share/PFlowHiveExOpts.py
index 4d6acd69dda08622d2d1f45db706db9c115fb128..47a9665ef274201f6c078afb673ad535d81681c4 100644
--- a/Reconstruction/eflowRec/share/PFlowHiveExOpts.py
+++ b/Reconstruction/eflowRec/share/PFlowHiveExOpts.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 # Runs calorimeter clustering reconstruction - this part is taken from CaloHiveExOpts.py
 # Additional configuration runs particle flow MT algorithms and sets up items needed for track to calorimeter extrapolation
@@ -149,7 +149,7 @@ include("eflowRec/PFlowMTConfig.py")
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 include ("CaloRecEx/CaloRecOutputItemList_jobOptions.py")
diff --git a/Reconstruction/tauRec/share/run_tau_standalone.py b/Reconstruction/tauRec/share/run_tau_standalone.py
index cbf3c54a23b7e5adfbea03b8f4370b734bf7cb0e..e1893d8c36eb0518f223856783454bd3a26c4774 100644
--- a/Reconstruction/tauRec/share/run_tau_standalone.py
+++ b/Reconstruction/tauRec/share/run_tau_standalone.py
@@ -1,5 +1,5 @@
 #
-#  Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+#  Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 #
 # job options to run tau reco on an ESD file  
  
@@ -139,7 +139,7 @@ jobproperties.CaloCellFlags.doLArDeadOTXCorr=False
 
 import AthenaPoolCnvSvc.WriteAthenaPool
 logRecoOutputItemList_jobOptions = logging.getLogger( 'py:RecoOutputItemList_jobOptions' )
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 print StreamESD.ItemList
diff --git a/Trigger/TrigSteer/TrigSteering/share/pureSteering_jobOptionsWithPoolOutput.py b/Trigger/TrigSteer/TrigSteering/share/pureSteering_jobOptionsWithPoolOutput.py
index 19e74cda12e137fc198196d9fbdf8f2ca68c5dc9..1671c5da6d55ffe532b35b790bd2e792a9fd6ddb 100755
--- a/Trigger/TrigSteer/TrigSteering/share/pureSteering_jobOptionsWithPoolOutput.py
+++ b/Trigger/TrigSteer/TrigSteering/share/pureSteering_jobOptionsWithPoolOutput.py
@@ -111,7 +111,7 @@ import AthenaPoolCnvSvc.WriteAthenaPool
 from AthenaCommon.AppMgr import ServiceMgr as svcMgr
 svcMgr.PoolSvc.WriteCatalog = "xmlcatalog_file:Catalogue1.xml"
 
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 stream = createOutputStream( "Stream1" )
 
 #from AthenaPoolCnvSvc.WriteAthenaPool import AthenaPoolOutputStream
diff --git a/Trigger/TrigValidation/TrigUpgradeTest/share/photon.withViews.py b/Trigger/TrigValidation/TrigUpgradeTest/share/photon.withViews.py
index dc4eb41fe90cc565e7fabfd4ebcb77761e491acd..f0b0bb7d0e97e61e55934f3219c06aa7bfa7702c 100644
--- a/Trigger/TrigValidation/TrigUpgradeTest/share/photon.withViews.py
+++ b/Trigger/TrigValidation/TrigUpgradeTest/share/photon.withViews.py
@@ -132,7 +132,7 @@ from TrigUpgradeTest.TestUtils import MenuTest
 mon.HLTTriggerMenu = [ x.split(":")[1] for x in  MenuTest.CTPToChainMapping ]
 
 import AthenaPoolCnvSvc.WriteAthenaPool
-from OutputStreamAthenaPool.OutputStreamAthenaPool import  createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import  createOutputStream
 StreamESD=createOutputStream("StreamESD","myESD.pool.root",True)
 topSequence.remove( StreamESD )
 
diff --git a/Trigger/TriggerCommon/TriggerJobOpts/share/decodeBS.py b/Trigger/TriggerCommon/TriggerJobOpts/share/decodeBS.py
index 4a2e041d1a4970b4a82c7ed25f9456bb40476446..82bd3b52edd955b4d4108f69286f0aa6365a35a3 100644
--- a/Trigger/TriggerCommon/TriggerJobOpts/share/decodeBS.py
+++ b/Trigger/TriggerCommon/TriggerJobOpts/share/decodeBS.py
@@ -40,7 +40,7 @@ decodingSeq += deserialiser
 topSequence += decodingSeq
 
 # Create OutputStream for ESD writing
-from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
 StreamESD = createOutputStream("StreamESD","ESD.pool.root",True)
 topSequence.remove( StreamESD )
 outSequence.remove( StreamESD )
diff --git a/Trigger/TriggerSimulation/TrigSimTransforms/share/MergingEventLoopMgr_TriggerBSandRDOtoRDO.py b/Trigger/TriggerSimulation/TrigSimTransforms/share/MergingEventLoopMgr_TriggerBSandRDOtoRDO.py
index 0d04ed67702a579526402ad2afe1782cb4894b48..a5e3aedd2d02bb17b18cf0b568b77f6b702334b0 100644
--- a/Trigger/TriggerSimulation/TrigSimTransforms/share/MergingEventLoopMgr_TriggerBSandRDOtoRDO.py
+++ b/Trigger/TriggerSimulation/TrigSimTransforms/share/MergingEventLoopMgr_TriggerBSandRDOtoRDO.py
@@ -186,7 +186,7 @@ svcMgr.AthenaSealSvc.CheckDictionary = True
 #svcMgr.AthenaSealSvc.CheckDictAtInit = True
 
 
-from OutputStreamAthenaPool.OutputStreamAthenaPool import AthenaPoolOutputStream
+from OutputStreamAthenaPool.CreateOutputStreams import AthenaPoolOutputStream
 ostream = AthenaPoolOutputStream("StreamRDO", athenaCommonFlags.PoolRDOOutput(), True)
 
 ostream.TakeItemsFromInput = True
diff --git a/Trigger/TrigAnalysis/TrigDecisionMaker/python/TrigDecisionMakerConfig.py b/Trigger/TrigAnalysis/TrigDecisionMaker/python/TrigDecisionMakerConfig.py
index 8be4b3024fe29df37179c078bd46823b64118bbb..7686550ecb7ab73121aa5590c4949ecc6e2afe59 100644
--- a/Trigger/TrigAnalysis/TrigDecisionMaker/python/TrigDecisionMakerConfig.py
+++ b/Trigger/TrigAnalysis/TrigDecisionMaker/python/TrigDecisionMakerConfig.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2017 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
 
 from TrigDecisionMaker.TrigDecisionMakerConf import TrigDec__TrigDecisionMaker
 from TrigDecisionMaker.TrigDecisionMakerConf import TrigDec__TrigDecisionMakerMT
@@ -41,7 +41,7 @@ class TrigDecisionStream ( object) :
         from AthenaCommon.AppMgr import ServiceMgr as svcMgr
         svcMgr.PoolSvc.WriteCatalog = catalog
 
         # revert later from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
         # revert later self.stream = createOutputStream( streamName )
 
         from AthenaPoolCnvSvc.WriteAthenaPool import AthenaPoolOutputStream
@@ -75,7 +75,7 @@ class TrigConditionStream ( object) :
         svcMgr += PoolSvc()
         svcMgr.PoolSvc.WriteCatalog = catalog
 
-        from OutputStreamAthenaPool.OutputStreamAthenaPool import AthenaPoolOutputConditionStream
+        from OutputStreamAthenaPool.CreateOutputStreams import AthenaPoolOutputConditionStream
         self.stream = AthenaPoolOutputConditionStream( streamName )
 
         from AthenaPoolCnvSvc.WriteAthenaPool import AthenaPoolOutputStream
@@ -41,7 +41,7 @@ class TrigDecisionStream ( object) :
         svcMgr.PoolSvc.WriteCatalog = catalog
 
-        # revert later from OutputStreamAthenaPool.OutputStreamAthenaPool import createOutputStream
+        # revert later from OutputStreamAthenaPool.CreateOutputStreams import createOutputStream
         # revert later self.stream = createOutputStream( streamName )
 